summaryrefslogtreecommitdiffstats
path: root/src/H5VLconnector.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/H5VLconnector.h')
-rw-r--r--src/H5VLconnector.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/H5VLconnector.h b/src/H5VLconnector.h
index 62929ee..9de518f 100644
--- a/src/H5VLconnector.h
+++ b/src/H5VLconnector.h
@@ -107,7 +107,8 @@ typedef enum H5VL_file_specific_t {
H5VL_FILE_REOPEN, /* Reopen the file */
H5VL_FILE_MOUNT, /* Mount a file */
H5VL_FILE_UNMOUNT, /* Unmount a file */
- H5VL_FILE_IS_ACCESSIBLE /* Check if a file is accessible */
+ H5VL_FILE_IS_ACCESSIBLE, /* Check if a file is accessible */
+ H5VL_FILE_DELETE /* Delete a file */
} H5VL_file_specific_t;
/* types for group GET callback */